Meta-Analysis
=============

.. toctree::

   reference_nice_stats_profile_ordinal
   reference_xyy_to_profile
   reference_binary_axes_subplot_poisson
   reference_binary_figure
   reference_binary_plot_convergence
   reference_binary_plot_n_equilibria
   reference_binary_plot_winners_at_equilibrium
   reference_binary_plot_winning_frequencies
   reference_simplex_to_profile
   reference_ternary_axes_subplot_poisson
   reference_ternary_figure
   reference_ternary_plot_convergence
   reference_ternary_plot_n_equilibria
   reference_ternary_plot_winners_at_equilibrium
   reference_ternary_plot_winning_frequencies
